# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class PackageIn(BaseModel):
    """
    PackageIn
    """ # noqa: E501
    title: StrictStr
    payment_type: Optional[StrictStr] = 'free'
    direct_link_slug: Optional[StrictStr] = None
    sales_page_url: Optional[StrictStr] = None
    expired_message: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["title", "payment_type", "direct_link_slug", "sales_page_url", "expired_message"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PackageIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if direct_link_slug (nullable) is None
        # and model_fields_set contains the field
        if self.direct_link_slug is None and "direct_link_slug" in self.model_fields_set:
            _dict['direct_link_slug'] = None

        # set to None if sales_page_url (nullable) is None
        # and model_fields_set contains the field
        if self.sales_page_url is None and "sales_page_url" in self.model_fields_set:
            _dict['sales_page_url'] = None

        # set to None if expired_message (nullable) is None
        # and model_fields_set contains the field
        if self.expired_message is None and "expired_message" in self.model_fields_set:
            _dict['expired_message'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PackageIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "payment_type": obj.get("payment_type") if obj.get("payment_type") is not None else 'free',
            "direct_link_slug": obj.get("direct_link_slug"),
            "sales_page_url": obj.get("sales_page_url"),
            "expired_message": obj.get("expired_message")
        })
        return _obj


