# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector_v2.api.server_api import ServerApi


class TestServerApi(unittest.IsolatedAsyncioTestCase):
    """ServerApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ServerApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_check_v1_access_check_post(self) -> None:
        """Test case for check_v1_access_check_post

        Check a single resource
        """
        pass

    async def test_consume_v1_admin_consume_post(self) -> None:
        """Test case for consume_v1_admin_consume_post

        Apply an access.order-events payload
        """
        pass

    async def test_resolve_v1_access_resolve_post(self) -> None:
        """Test case for resolve_v1_access_resolve_post

        Resolve a resource tree
        """
        pass

    async def test_resources_summary_v1_access_members_member_id_resources_get(self) -> None:
        """Test case for resources_summary_v1_access_members_member_id_resources_get

        List the granted resources (of a type) a member reaches
        """
        pass


if __name__ == '__main__':
    unittest.main()
